@@ -1,6 +1,6 @@
-from django.conf import settings
 from rest_framework import serializers
 
+from django_burl.conf import settings
 from django_burl.models import BriefURL
 
 
