@@ -1,8 +1,9 @@
 import logging
-from django.conf import settings
 from django.db import connection, connections
 from django.db.models.query import QuerySet
 
+from django_burl.conf import settings
+
 logger = logging.getLogger(__name__)
 
 
