@@ -6,6 +6,7 @@ from rest_framework.authtoken.models import Token
 from rest_framework.test import APITestCase
 
 from django_burl.models import BriefURL, BriefURLDomainUser
+from django_burl.conf import settings
 
 
 class BurlApiTestCase(APITestCase):
@@ -50,6 +51,21 @@ class BurlApiTestCase(APITestCase):
         BriefURLDomainUser.objects.create(
             site=cls.site2, user=cls.farnsworth, role=BriefURLDomainUser.Role.ADMIN
         )
+        if (
+            "rest_framework_simplejwt.authentication.JWTAuthentication"
+            in settings.REST_FRAMEWORK["DEFAULT_AUTHENTICATION_CLASSES"]
+        ):
+            cls.simplejwt = True
+        else:
+            cls.simplejwt = False
+
+    # for some reason, enabling simplejwt causes unauthorized requests to raise
+    # 401 instead of 403; the end result is the same, so test for either case
+    def assert_401_or_403(self, status_code):
+        if self.simplejwt:
+            return self.assertEquals(status_code, 401)
+        else:
+            return self.assertEquals(status_code, 403)
 
 
 class BurlCreateTests(BurlApiTestCase):
@@ -86,7 +102,7 @@ class BurlCreateTests(BurlApiTestCase):
     def test_create_random_unauthorized(self):
         data = {"url": "https://en.wikipedia.org", "user": self.kif.id}
         response = self.client.post(reverse("burls:burls-list"), data, format="json")
-        self.assertEquals(response.status_code, 401)
+        self.assert_401_or_403(response.status_code)
 
     def test_create_random_no_domain_user(self):
         data = {"url": self.url, "user": self.zoidberg.id}
@@ -252,7 +268,7 @@ class BurlReadTests(BurlApiTestCase):
         redirect = BriefURL.objects.create(user=self.amy, url=self.url, site=self.site)
         url = reverse("burls:burls-detail", kwargs={"burl": redirect.burl})
         response = self.client.get(url)
-        self.assertEquals(response.status_code, 401)
+        self.assert_401_or_403(response.status_code)
 
     def test_list_as_creator(self):
         BriefURL.objects.create(user=self.fry, url=self.url, site=self.site)
@@ -311,7 +327,7 @@ class BurlReadTests(BurlApiTestCase):
         BriefURL.objects.create(user=self.amy, url=self.url, site=self.site)
         url = reverse("burls:burls-list")
         response = self.client.get(url)
-        self.assertEquals(response.status_code, 401)
+        self.assert_401_or_403(response.status_code)
 
 
 class BurlUpdateTests(BurlApiTestCase):
@@ -414,7 +430,7 @@ class BurlUpdateTests(BurlApiTestCase):
         }
         url = reverse("burls:burls-detail", kwargs={"burl": redirect.burl})
         response = self.client.patch(url, data, format="json")
-        self.assertEquals(response.status_code, 401)
+        self.assert_401_or_403(response.status_code)
 
     def test_update_put_by_creator_as_creator(self):
         redirect = BriefURL.objects.create(
@@ -477,7 +493,7 @@ class BurlUpdateTests(BurlApiTestCase):
         }
         url = reverse("burls:burls-detail", kwargs={"burl": redirect.burl})
         response = self.client.put(url, data, format="json")
-        self.assertEquals(response.status_code, 401)
+        self.assert_401_or_403(response.status_code)
 
     def test_update_site2_burl_as_site1_editor(self):
         redirect = BriefURL.objects.create(
@@ -559,5 +575,5 @@ class BurlDeleteTests(BurlApiTestCase):
         redirect = BriefURL.objects.create(user=self.amy, url=self.url, site=self.site)
         url = reverse("burls:burls-detail", kwargs={"burl": redirect.burl})
         response = self.client.delete(url)
-        self.assertEquals(response.status_code, 401)
+        self.assert_401_or_403(response.status_code)
         self.assertEquals(len(BriefURL.objects.filter(burl=redirect.burl)), 1)
